@@ -1,16 +1,16 @@
 package ColorThemeBase::Static;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-07'; # DATE
+our $DATE = '2020-06-08'; # DATE
 our $DIST = 'ColorThemeBase-Static'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use strict 'subs', 'vars';
 #use warnings;
 
 use parent 'ColorThemeBase::Constructor';
 
-sub get_color_list {
+sub list_items {
     my $self = shift;
 
     my $theme_hash = \%{"$self->{orig_class}::THEME"};
@@ -52,7 +52,7 @@ ColorThemeBase::Static - Base class for color theme modules with static list of
 
 =head1 VERSION
 
-This document describes version 0.003 of ColorThemeBase::Static (from Perl distribution ColorThemeBase-Static), released on 2020-06-07.
+This document describes version 0.004 of ColorThemeBase::Static (from Perl distribution ColorThemeBase-Static), released on 2020-06-08.
 
 =head1 DESCRIPTION
 
